.. _api-reference:

===
API
===

This part of the documentation covers all the public interfaces of *Mimesis*.

Random module
=============

.. autoclass:: mimesis.random.Random
   :members:
   :special-members: __init__

Keys module
===========

.. automodule:: mimesis.keys
   :members:

Shortcuts
=========

.. automodule:: mimesis.shortcuts
   :members:


Custom Exceptions
=================

.. automodule:: mimesis.exceptions
   :members:


Base Providers
==============

BaseProvider
------------

.. autoclass:: mimesis.providers.BaseProvider
   :members:
   :special-members: __init__

BaseDataProvider
----------------

.. autoclass:: mimesis.providers.BaseDataProvider
   :members:
   :special-members: __init__


Generic Providers
=================

Generic
-------

.. autoclass:: mimesis.Generic
   :members:
   :special-members: __init__



Localized Providers
===================

Address
-------

.. autoclass:: mimesis.Address
   :members:
   :special-members: __init__

Finance
-------

.. autoclass:: mimesis.Finance
   :members:
   :special-members: __init__

Datetime
--------

.. autoclass:: mimesis.Datetime
   :members:
   :special-members: __init__

Food
----
.. autoclass:: mimesis.Food
   :members:
   :special-members: __init__

Person
--------

.. autoclass:: mimesis.Person
   :members:
   :special-members: __init__

Text
----

.. autoclass:: mimesis.Text
   :members:
   :special-members: __init__


Universal Providers
===================

BinaryFile
----------

.. autoclass:: mimesis.BinaryFile
   :members:
   :special-members: __init__

Code
----

.. autoclass:: mimesis.Code
   :members:
   :special-members: __init__

Choice
------

.. autoclass:: mimesis.Choice
   :members:
   :special-members: __init__

Cryptographic
-------------

.. autoclass:: mimesis.Cryptographic
   :members:
   :special-members: __init__

Development
-----------

.. autoclass:: mimesis.Development
   :members:
   :special-members: __init__

File
----

.. autoclass:: mimesis.File
   :members:
   :special-members: __init__

Hardware
--------

.. autoclass:: mimesis.Hardware
   :members:
   :special-members: __init__

Internet
--------

.. autoclass:: mimesis.Internet
   :members:
   :special-members: __init__

Numeric
-------

.. autoclass:: mimesis.Numeric
   :members:
   :special-members: __init__

Path
----

.. autoclass:: mimesis.Path
   :members:
   :special-members: __init__

Payment
-------

.. autoclass:: mimesis.Payment
   :members:
   :special-members: __init__

Transport
---------

.. autoclass:: mimesis.Transport
   :members:
   :special-members: __init__


Science
-------

.. autoclass:: mimesis.Science
   :members:
   :special-members: __init__


Schema-based Generators
=======================

BaseField
---------

.. autoclass:: mimesis.schema.BaseField
   :members:
   :special-members: __call__, __init__

Field
------

.. autoclass:: mimesis.schema.Field
   :members:

Fieldset
--------

.. autoclass:: mimesis.schema.Fieldset
   :members:

Schema
------

.. autoclass:: mimesis.schema.Schema
   :members:
   :special-members: __init__


SchemaContext
-------------

.. autoclass:: mimesis.schema.SchemaContext
   :members:
   :special-members: __init__


SchemaBuilder
-------------

.. autoclass:: mimesis.schema.SchemaBuilder
   :members:
   :special-members: __init__



Enums
=====

.. automodule:: mimesis.enums
   :members:
   :undoc-members:
